# Автоматизированная публикация пакета

## Введение

Этот документ описывает процесс автоматизированной публикации пакета `mcp_proxy_adapter` на PyPI с использованием разработанных скриптов.

## Скрипты для публикации

В проекте имеются следующие скрипты для автоматизации процесса публикации:

1. `scripts/publish_and_test.py` - основной скрипт для публикации и тестирования
2. `scripts/test_install.py` - скрипт для проверки корректности установки пакета

## Процесс публикации

### 1. Подготовка к публикации

Перед публикацией необходимо проверить:
- Все необходимые изменения внесены в код
- Тесты успешно проходят
- Документация обновлена

### 2. Автоматизированная публикация

Для публикации пакета используйте скрипт `publish_and_test.py`:

```bash
# Обновление версии и публикация на основной PyPI
python scripts/publish_and_test.py --version 3.0.1

# Публикация на TestPyPI
python scripts/publish_and_test.py --test

# Только сборка пакета без публикации
python scripts/publish_and_test.py --build-only
```

### 3. Что делает скрипт публикации

Скрипт `publish_and_test.py` выполняет следующие действия:

1. **Обновление версии** (при указании параметра `--version`):
   - Обновляет версию в файле `mcp_proxy_adapter/version.py`
   - Добавляет новую запись в файлы `CHANGELOG.md` и `CHANGELOG_ru.md`

2. **Сборка пакета**:
   - Очищает предыдущие сборки
   - Создает архивы `.tar.gz` и `.whl`

3. **Публикация пакета**:
   - Загружает пакет на PyPI или TestPyPI

4. **Тестирование установки**:
   - Создает изолированное окружение
   - Устанавливает пакет
   - Проверяет корректность установки
   - Тестирует создание проекта

### 4. Ручное тестирование

Для ручного тестирования установки пакета можно использовать скрипт `test_install.py`:

```bash
python scripts/test_install.py
```

## Требования

Для использования скриптов публикации требуются следующие инструменты:

1. Python 3.6 или выше
2. Модули `build` и `twine`:
   ```bash
   pip install build twine
   ```
3. Настроенный доступ к PyPI (файл `.pypirc` или переменные окружения)

## Настройка доступа к PyPI

### 1. Через файл конфигурации

Создайте файл `~/.pypirc` со следующим содержимым:

```ini
[distutils]
index-servers =
    pypi
    testpypi

[pypi]
username = __token__
password = pypi-API-токен

[testpypi]
repository = https://test.pypi.org/legacy/
username = __token__
password = testpypi-API-токен
```

### 2. Через переменные окружения

```bash
export TWINE_USERNAME=__token__
export TWINE_PASSWORD=pypi-API-токен
```

## Устранение проблем

### Ошибка при публикации

Если возникает ошибка при публикации пакета, проверьте:
1. Корректность учетных данных для PyPI
2. Уникальность версии пакета (нельзя повторно загрузить уже опубликованную версию)
3. Соответствие имени пакета требованиям PyPI

### Ошибка при установке

Если пакет установлен, но возникают ошибки при импорте:
1. Проверьте, все ли необходимые файлы включены в пакет (MANIFEST.in)
2. Убедитесь, что зависимости указаны корректно в setup.py или pyproject.toml
3. Попробуйте установить пакет в отладочном режиме: `pip install -v mcp_proxy_adapter` 