# Стандарты документации

**Содержание**: 1. Основные принципы • 2. Структура файлов • 3. Правила форматирования • 4. Требования к двуязычности • 5. Инструменты

## 1. Основные принципы

### 1.1. Единый источник истины
Каждый аспект проекта должен иметь единственный авторитетный источник документации. Вместо дублирования следует использовать перекрестные ссылки.

### 1.2. Эквивалентность языковых версий
Вся документация должна существовать как на английском, так и на русском языках с идентичной структурой, содержанием, примерами и форматированием.

### 1.3. Машинная читаемость
Документация должна форматироваться таким образом, чтобы она легко обрабатывалась инструментами документации, языковыми моделями и поисковыми системами.

### 1.4. Подход, ориентированный на разработчика
Документация должна быть организована так, чтобы разработчикам было легко быстро находить информацию и однозначно понимать требования.

## 2. Структура файлов

### 2.1. Корневые файлы документации
Следующие файлы должны существовать на корневом уровне документации в директориях EN и RU:

| Файл                     | Назначение                                       |
|--------------------------|--------------------------------------------------|
| PROJECT_RULES.md         | Общие правила и управление проектом              |
| NAMING_STANDARDS.md      | Соглашения об именовании и стандарты структуры   |
| COMMAND_CHECKLIST.md     | Чек-лист для реализации новых команд             |
| GLOSSARY.md              | Определения терминологии, используемой в проекте |
| DOCUMENTATION_STANDARDS.md | Требования к документации и правила форматирования |

### 2.2. Документация команд
Каждая команда должна иметь отдельный файл документации:
- Расположение: `docs/{LANG}/commands/{command_name}_command.md`
- Должен включать все обязательные разделы (см. Раздел 3.3)

### 2.3. Перекрестные ссылки
Используйте ссылки на относительные пути для ссылки на связанную документацию:
```markdown
См. [определение CommandResult](../GLOSSARY.md#commandresult) для получения подробной информации.
```

## 3. Правила форматирования

### 3.1. Синтаксис Markdown
- Используйте стандартный GitHub Flavored Markdown
- Заголовки должны использовать стиль ATX (#, ##, ###)
- Все блоки кода должны указывать идентификаторы языка:
  ```python
  def example_code():
      return "Это правильно отформатировано"
  ```

### 3.2. Нумерация разделов
Используйте последовательную нумерацию разделов в формате:
```
# Главный заголовок

## 1. Первый раздел
### 1.1. Подраздел

## 2. Второй раздел
### 2.1. Подраздел
```

### 3.3. Обязательные разделы в документации команд
1. **Обзор** - Краткое описание назначения команды
2. **Параметры** - Таблица с именем, типом, описанием, статусом обязательности
3. **Результат** - Описание и структура возвращаемого значения
4. **Примеры** - Примеры кода на Python, JSON-RPC и в формате HTTP REST
5. **Детали реализации** - Примечания о специфике реализации
6. **Обработка ошибок** - Возможные условия ошибок и их ответы

### 3.4. Примеры кода
Каждая документация команды должна включать примеры в:
- Python код
- Запрос/ответ JSON-RPC
- Запрос/ответ HTTP REST (если применимо)

## 4. Требования к двуязычности

### 4.1. Эквивалентность файлов
- Каждый файл документации должен существовать как в директории `/docs/EN/`, так и в директории `/docs/RU/`
- Файлы должны иметь идентичные имена в обеих директориях
- Структура разделов должна быть идентичной

### 4.2. Синхронизация содержимого
- Обновления должны вноситься в обе языковые версии одновременно
- Примеры кода должны быть идентичны в обеих версиях
- Диаграммы и схемы должны быть идентичны (могут быть переведены только текстовые метки)

### 4.3. Качество перевода
- Технические термины в русской документации должны сопровождаться их английскими эквивалентами в скобках
- Для обеспечения согласованности используйте утвержденные переводы из глоссария

## 5. Инструменты

### 5.1. Проверки валидации
- Используйте конвейеры CI/CD для проверки двуязычной согласованности
- Проверяйте наличие неработающих ссылок

### 5.2. Генерация документации
- Документация API генерируется из аннотаций кода и схем
- Примеры команд должны проверяться на соответствие последнему коду

### 5.3. Проверка стиля
- Используйте линтеры markdown для обеспечения единообразного форматирования
- Обеспечивайте нумерацию разделов и наличие обязательных разделов

## 6. Сопровождение

### 6.1. Процесс проверки
- Изменения в документации должны проверяться вместе с изменениями в коде
- В процессе проверки следует проверять двуязычную согласованность

### 6.2. Маркировка устаревших элементов
- Устаревшие функции должны быть четко отмечены в документации
- Включайте руководство по миграции для устаревших функций 