# Глоссарий MCP Microservice

**Содержание**: 1. Основные концепции • 2. Архитектура • 3. Компоненты команд • 4. Стандарты документации

## 1. Основные концепции

### Команда (Command)
Дискретная единица функциональности, выполняющая определенную задачу и возвращающая стандартизированный результат. В MCP команды реализуются как Python-функции с декоратором `@registry.command`.

### Реестр команд (Command Registry)
Центральная система, управляющая регистрацией, обнаружением и метаданными команд. Предоставляет интерфейсы для выполнения команд через JSON-RPC и REST API.

### JSON-RPC
Основной протокол, используемый для выполнения команд в MCP. Позволяет вызывать методы с именованными параметрами и стандартизированной обработкой ошибок.

## 2. Архитектура

### Микросервис (Microservice)
Самодостаточный сервис, реализующий определенный набор связанных функций и способный развертываться независимо.

### MCP Адаптер (MCP Adapter)
Компонент, осуществляющий перевод между внешними системами и микросервисами MCP, обеспечивающий стандартизированные каналы коммуникации.

### Прокси (Proxy)
Промежуточный компонент, маршрутизирующий запросы к соответствующим обработчикам и выполняющий дополнительные задачи, такие как аутентификация, логирование и трансформация запросов.

## 3. Компоненты команд

### CommandResult
Базовый класс для всех объектов результатов команд. Предоставляет методы сериализации, такие как `to_dict()` и генерацию схемы через `get_schema()`.

### Класс результата (Result Class)
Dataclass, наследующийся от CommandResult и определяющий структуру возвращаемого значения команды.

### Функция команды (Command Function)
Асинхронная функция, декорированная `@registry.command`, реализующая бизнес-логику команды.

### Валидация параметров (Parameter Validation)
Процесс проверки входных данных команды на соответствие определенным схемам перед выполнением.

## 4. Стандарты документации

### Двуязычная документация (Bilingual Documentation)
Требование поддерживать всю документацию как на английском, так и на русском языках с идентичной структурой и содержанием.

### Документация команд (Command Documentation)
Markdown-файлы, описывающие команды, их параметры, возвращаемые значения и примеры использования.

### Блок кода (Code Block)
Раздел документации, содержащий примеры кода, отмеченные тройными обратными кавычками и идентификатором языка (```python, ```json).

### Схема (Schema)
JSON-структура, определяющая ожидаемый формат параметров команд и результатов, используемая для валидации и генерации документации API. 