# Эндпоинт /cmd

## Описание

Эндпоинт `/cmd` представляет собой универсальный интерфейс для выполнения команд микросервиса. Он предоставляет упрощенный способ взаимодействия с командами по сравнению с полным JSON-RPC протоколом.

Особенности эндпоинта:
- Единый URL для всех команд
- Упрощенный формат запроса и ответа
- Стандартизированная обработка ошибок
- Совместимость с форматом MCP Proxy

## Формат запроса

Запрос к эндпоинту `/cmd` имеет следующий формат:

```json
{
    "command": "имя_команды",
    "params": {
        "параметр1": "значение1",
        "параметр2": "значение2"
    }
}
```

### Поля запроса

| Поле | Тип | Обязательное | Описание |
|------|-----|-------------|----------|
| `command` | string | Да | Имя команды для выполнения |
| `params` | object | Нет | Параметры команды (зависят от типа команды) |

## Формат ответа

Успешный ответ от эндпоинта `/cmd` имеет следующий формат:

```json
{
    "result": {
        // Результат выполнения команды
    }
}
```

В случае ошибки ответ имеет следующий формат:

```json
{
    "error": {
        "code": -32601,
        "message": "Команда не найдена",
        "data": {
            // Дополнительная информация об ошибке (опционально)
        }
    }
}
```

### Стандартные коды ошибок

| Код | Описание |
|-----|----------|
| -32700 | Parse error - ошибка разбора JSON |
| -32600 | Invalid Request - неверный формат запроса |
| -32601 | Method not found - команда не найдена |
| -32602 | Invalid params - неверные параметры |
| -32603 | Internal error - внутренняя ошибка сервера |
| -32000 до -32099 | Пользовательские ошибки |

## Реализация

Эндпоинт `/cmd` реализован с использованием FastAPI. Основной процесс обработки запроса включает:

1. Извлечение имени команды и параметров из тела запроса
2. Проверка существования команды в реестре
3. Выполнение команды с переданными параметрами
4. Формирование ответа на основе результата или ошибки

Важной особенностью реализации является то, что все ответы, включая ошибки, возвращаются с HTTP-кодом 200. Информация об ошибках содержится в теле ответа.

## Примеры

### Запрос с командой help

```http
POST /cmd HTTP/1.1
Content-Type: application/json

{
    "command": "help"
}
```

### Ответ

```json
{
    "result": {
        "commands": {
            "help": {
                "description": "Получение справочной информации о доступных командах"
            },
            "health": {
                "description": "Проверка состояния сервера"
            }
        }
    }
}
```

### Запрос с командой health

```http
POST /cmd HTTP/1.1
Content-Type: application/json

{
    "command": "health",
    "params": {
        "check_type": "detailed"
    }
}
```

### Ответ

```json
{
    "result": {
        "status": "ok",
        "uptime": 3600,
        "memory_usage": {
            "total": 1024,
            "used": 512
        },
        "services": {
            "database": "connected",
            "cache": "connected"
        }
    }
}
```

### Запрос с несуществующей командой

```http
POST /cmd HTTP/1.1
Content-Type: application/json

{
    "command": "несуществующая_команда"
}
```

### Ответ

```json
{
    "error": {
        "code": -32601,
        "message": "Команда 'несуществующая_команда' не найдена"
    }
}
```

## Отличия от JSON-RPC

Формат запросов и ответов эндпоинта `/cmd` имеет следующие отличия от стандарта JSON-RPC 2.0:

1. **Упрощенный формат запроса**:
   - Поле `command` вместо `method`
   - Отсутствие полей `jsonrpc` и `id`

2. **Упрощенный формат ответа**:
   - Отсутствие полей `jsonrpc` и `id`
   - Результат или ошибка возвращаются на верхнем уровне 