# Ошибки API

## Формат ошибок

Все ошибки, возвращаемые API, соответствуют спецификации JSON-RPC 2.0. Ответ с ошибкой имеет следующую структуру:

```json
{
  "jsonrpc": "2.0",
  "error": {
    "code": -32603,
    "message": "Internal error",
    "data": {
      "details": "Additional error information"
    }
  },
  "id": 1
}
```

## Стандартные коды ошибок

API использует стандартные коды ошибок JSON-RPC 2.0:

| Код | Сообщение | Описание |
|-----|-----------|----------|
| -32700 | Parse error | Получен недопустимый JSON |
| -32600 | Invalid request | Отправленный JSON не является действительным объектом запроса |
| -32601 | Method not found | Метод не существует или недоступен |
| -32602 | Invalid params | Недопустимый параметр(ы) метода |
| -32603 | Internal error | Внутренняя ошибка JSON-RPC |
| -32000 to -32099 | Server error | Зарезервировано для ошибок сервера, определяемых реализацией |

## Пользовательские коды ошибок

В дополнение к стандартным кодам ошибок, API определяет пользовательские коды ошибок для конкретных условий:

| Код | Сообщение | Описание |
|-----|-----------|----------|
| -32001 | Validation error | Параметры запроса не прошли валидацию |
| -32002 | Authorization error | В запросе отсутствуют действительные учетные данные для аутентификации |
| -32003 | Resource not found | Запрашиваемый ресурс не найден |
| -32004 | Resource conflict | Запрос конфликтует с текущим состоянием ресурса |
| -32005 | Rate limit exceeded | Превышен лимит скорости запросов |
| -32006 | Command execution error | Произошла ошибка при выполнении команды |

## Данные об ошибке

Поле `data` объекта ошибки содержит дополнительную информацию об ошибке. Структура поля данных зависит от кода ошибки:

### Ошибка валидации (-32001)

```json
{
  "jsonrpc": "2.0",
  "error": {
    "code": -32001,
    "message": "Validation error",
    "data": {
      "errors": [
        {
          "field": "name",
          "message": "Это поле обязательно"
        },
        {
          "field": "age",
          "message": "Должно быть положительное целое число"
        }
      ]
    }
  },
  "id": 1
}
```

### Ошибка выполнения команды (-32006)

```json
{
  "jsonrpc": "2.0",
  "error": {
    "code": -32006,
    "message": "Command execution error",
    "data": {
      "command": "hello_world",
      "reason": "Недопустимый параметр name",
      "details": "Имя должно быть строкой"
    }
  },
  "id": 1
}
```

## Лучшие практики обработки ошибок

1. Всегда проверяйте наличие ошибок в ответе
2. Соответствующим образом обрабатывайте конкретные коды ошибок
3. Записывайте детали ошибок для отладки
4. Повторяйте запросы с экспоненциальной задержкой для временных ошибок (ошибок сервера)
5. Отображайте понятные для пользователя сообщения об ошибках 