# Руководство по удалению команд

Данное руководство описывает правильную процедуру удаления команд из MCP Proxy Adapter.

## Обзор

Когда команда больше не нужна, важно полностью удалить все связанные с ней компоненты, чтобы поддерживать кодовую базу в чистоте и облегчить её сопровождение. Простое комментирование или оставление неиспользуемых файлов в проекте может привести к путанице и техническому долгу.

## Полный чек-лист удаления

Для правильного удаления команды следуйте этим шагам:

- [ ] Удалить файл реализации команды (`{command_name}_command.py`)
- [ ] Удалить файл класса результата, если он существует в отдельном файле (`{command_name}_result.py`)
- [ ] Удалить файлы тестов (`test_{command_name}_command.py`)
- [ ] Удалить любые упоминания в документации
- [ ] Обновить примеры или учебные материалы, которые ссылаются на команду
- [ ] Проверить, что команда корректно отменена регистрация в реестре

## Пошаговая процедура

### 1. Удаление файлов команды

Удалите следующие файлы, связанные с командой:

```bash
# Удалить реализацию команды
rm mcp_microservice/commands/{command_name}_command.py

# Удалить файл результата, если он существует отдельно
rm mcp_microservice/commands/{command_name}_result.py

# Удалить файлы тестов
rm mcp_microservice/tests/commands/test_{command_name}_command.py
```

### 2. Перезапуск приложения

Команда будет автоматически отменена регистрация, потому что система автообнаружения не найдет удаленные файлы при следующем запуске приложения.

```bash
# Перезапустить приложение
# Механизм обнаружения реестра команд не найдет удаленные файлы
```

### 3. Ручная отмена регистрации (альтернатива)

Если вам нужно удалить команду без перезапуска приложения, вы можете вручную отменить ее регистрацию:

```python
from mcp_proxy_adapter.commands.command_registry import registry

# Отменить регистрацию команды по имени
registry.unregister("{command_name}")
```

Этот подход полезен в динамических сценариях, но обычно не нужен, так как команды обнаруживаются автоматически при запуске приложения.

### 4. Обновление документации

Убедитесь, что вы обновили всю документацию, которая ссылается на удаленную команду:

- Удалите примеры команды из соответствующих файлов документации
- Обновите любую документацию API, которая включает команду
- Обновите учебные материалы или руководства, которые используют команду

### 5. Обновление тестов

Если есть интеграционные тесты, которые используют команду, их следует обновить или удалить:

- Проверьте наличие тестовых случаев в `mcp_microservice/tests/integration/`, которые могут использовать команду
- Проверьте наличие тестовых случаев в `mcp_microservice/tests/api/`, которые могут ссылаться на конечные точки команды

### 6. Проверка удаления

Чтобы проверить, что команда была правильно удалена:

1. Запустите приложение
2. Проверьте, что команда не появляется в списке доступных команд
3. Убедитесь, что вызов удаленной команды возвращает ошибку "command not found"

```python
# Это должно вызвать NotFoundError или вернуть соответствующий ответ об ошибке
await registry.get_command("{command_name}")
```

## Примечания и соображения

### Зависимости между командами

Если удаляемая команда является зависимостью для других команд, убедитесь, что сначала обновите эти зависимые команды.

### Обратная совместимость

Рассмотрите, нарушит ли удаление команды обратную совместимость. Если команда является частью публичного API, рассмотрите:

- Сначала пометить её как устаревшую
- Предоставить альтернативные команды
- Сообщить пользователям об удалении до фактического удаления

### Поведение реестра команд

Реестр команд работает следующим образом:

1. При запуске приложения он сканирует директорию `mcp_microservice/commands/`
2. Он автоматически регистрирует все обнаруженные допустимые классы команд
3. Если файл команды удален, он не будет обнаружен при следующем сканировании
4. Ручная отмена регистрации может быть выполнена с помощью `registry.unregister()`

## Пример: Удаление команды "hello_world"

```bash
# Удалить файлы команды
rm mcp_microservice/commands/hello_world_command.py
rm mcp_microservice/commands/hello_world_result.py
rm mcp_microservice/tests/commands/test_hello_world_command.py

# Перезапустить приложение для применения изменений
# Реестр команд не найдет удаленные файлы команды hello_world
```

После перезапуска команда "hello_world" больше не будет доступна. 