# Архитектура

Этот документ описывает архитектуру сервиса MCP Proxy.

## Обзор

MCP Proxy построен на модульной архитектуре, основанной на командах. Основными компонентами являются:

1. **Слой API**: Обрабатывает HTTP-запросы и ответы
2. **Реестр команд**: Управляет доступными командами
3. **Реализации команд**: Фактическая логика команд
4. **Базовые утилиты**: Логирование, обработка ошибок и конфигурация

## Диаграмма компонентов

```
┌─────────────────┐     ┌─────────────────┐     ┌─────────────────┐
│     Клиент      │────▶│     Слой API    │────▶│  Реестр команд  │
└─────────────────┘     └─────────────────┘     └─────────────────┘
                                                         │
                                                         ▼
┌─────────────────┐     ┌─────────────────┐     ┌─────────────────┐
│ Базовые утилиты │◀───▶│ Выполнение команд │◀──│     Команды     │
└─────────────────┘     └─────────────────┘     └─────────────────┘
```

## Слой API

Слой API построен на FastAPI и предоставляет интерфейс JSON-RPC для выполнения команд. Он обрабатывает:

- Парсинг и валидацию запросов
- Диспетчеризацию команд
- Форматирование ответов
- Обработку ошибок
- Аутентификацию
- CORS

## Реестр команд

Реестр команд - это синглтон, который управляет всеми доступными командами. Он предоставляет:

- Регистрацию команд
- Поиск команд
- Метаданные команд
- Автоматическое обнаружение команд

## Реализации команд

Каждая команда реализуется как класс, наследующий от `BaseCommand`. Реализация команды включает:

- Класс команды
- Класс результата
- Валидацию параметров
- Бизнес-логику
- Обработку ошибок

## Базовые утилиты

Базовые утилиты предоставляют общую функциональность, используемую другими компонентами:

- Управление конфигурацией
- Логирование
- Обработка ошибок
- Вспомогательные утилиты

## Поток выполнения

1. Клиент отправляет JSON-RPC запрос на эндпоинт API
2. Слой API парсит и валидирует запрос
3. Команда ищется в Реестре команд
4. Команда инстанцируется и выполняется с предоставленными параметрами
5. Результат форматируется и возвращается клиенту
6. Все ошибки перехватываются, логируются и возвращаются как JSON-RPC ответы с ошибками

## Структура директорий

```
mcp_microservice/
├── __init__.py
├── api/                    # Реализация API
│   ├── __init__.py
│   ├── app.py              # Настройка приложения FastAPI
│   ├── handlers.py         # Обработчики запросов
│   ├── middleware.py       # Компоненты middleware API
│   └── schemas.py          # Определения схем API
├── commands/               # Реализации команд
│   ├── __init__.py
│   ├── base.py             # Базовый класс команды
│   ├── command_registry.py # Регистрация команд
│   └── result.py           # Классы результатов команд
├── core/                   # Базовая функциональность
│   ├── __init__.py
│   ├── errors.py           # Определения ошибок
│   ├── logging.py          # Настройка логирования
│   └── utils.py            # Утилитарные функции
└── main.py                 # Точка входа приложения
``` 