# Конфигурация

Это руководство описывает, как настроить сервис MCP Proxy.

## Файл конфигурации

Сервис MCP Proxy настраивается с помощью JSON-файла конфигурации. По умолчанию он ищет файл с именем `config.json` в текущей директории.

Вы можете указать другой файл конфигурации с помощью опции командной строки `--config`:

```bash
mcp-proxy --config /path/to/config.json
```

## Параметры конфигурации

Вот список доступных параметров конфигурации:

| Параметр | Тип | По умолчанию | Описание |
|----------|-----|--------------|----------|
| host | string | "0.0.0.0" | Хост, к которому привязывается сервис |
| port | number | 8000 | Порт для прослушивания |
| log_level | string | "INFO" | Уровень логирования (DEBUG, INFO, WARNING, ERROR, CRITICAL) |
| log_file | string | null | Путь к файлу логов (если null, логи выводятся в stdout) |
| log_rotation_type | string | "size" | Тип ротации логов ("size" или "time") |
| log_max_bytes | number | 10485760 | Максимальный размер файла лога в байтах (если rotation_type = "size") |
| log_backup_count | number | 5 | Количество резервных файлов логов для хранения |
| cors_origins | array | ["*"] | Список разрешенных CORS источников |
| api_keys | array | [] | Список действительных API-ключей (если пусто, аутентификация отключена) |

## Пример конфигурации

Вот пример файла конфигурации:

```json
{
  "host": "0.0.0.0",
  "port": 8000,
  "log_level": "INFO",
  "log_file": "logs/mcp_proxy.log",
  "log_rotation_type": "size",
  "log_max_bytes": 10485760,
  "log_backup_count": 5,
  "cors_origins": ["*"],
  "api_keys": ["your-api-key-here"]
}
```

## Переменные окружения

Вы также можете настроить сервис с помощью переменных окружения. Переменные окружения имеют приоритет над файлом конфигурации.

Формат переменной окружения: `MCP_UPPERCASE_OPTION_NAME`. Например, чтобы установить порт:

```bash
export MCP_PORT=8000
```

## Тестирование конфигурации

Для проверки конфигурации вы можете запустить сервис с опцией `--validate-config`:

```bash
mcp-proxy --config /path/to/config.json --validate-config
```

Это проверит файл конфигурации и завершит работу без запуска сервиса. 